@@ -1,6 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2009-2017 Brazil
+  Copyright(C) 2009-2018 Brazil
+  Copyright(C) 2018 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -18,14 +19,9 @@
 
 #pragma once
 
-#ifndef GRN_CTX_H
-# include "grn_ctx.h"
-#endif /* GRN_CTX_H */
-
-#ifndef GRN_COM_H
-# include "grn_com.h"
-#endif /* GRN_COM_H */
-
+#include "grn_ctx.h"
+#include "grn_com.h"
+#include "grn_options.h"
 #include "grn_msgpack.h"
 
 #ifdef GRN_WITH_MRUBY
@@ -97,6 +93,7 @@ typedef struct {
   char errbuf[GRN_CTX_MSGSIZE];
   grn_bool output_ids;
   grn_bool output_errors;
+  grn_bool lock_table;
 } grn_loader;
 
 #define GRN_CTX_N_SEGMENTS 512
@@ -212,6 +209,7 @@ struct _grn_ctx_impl {
 
   /* match escalation portion */
   int64_t match_escalation_threshold;
+  grn_bool force_match_escalation;
 
   /* lifetime portion */
   grn_proc_func *finalizer;
@@ -219,6 +217,7 @@ struct _grn_ctx_impl {
   grn_obj *db;
   grn_array *values;        /* temporary objects */
   grn_pat *temporary_columns;
+  grn_options *temporary_options;
   grn_hash *ios;        /* IOs */
   grn_com *com;
   unsigned int com_status;
