@@ -1,6 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
   Copyright(C) 2013-2018 Brazil
+  Copyright(C) 2018 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -125,6 +126,17 @@ grn_rc grn_expr_simple_function_call_get_arguments(grn_ctx *ctx,
                                                    grn_obj *expr,
                                                    grn_obj *arguments);
 
+grn_bool grn_expr_is_module_list(grn_ctx *ctx, grn_obj *expr);
+unsigned int grn_expr_module_list_get_n_modules(grn_ctx *ctx,
+                                                grn_obj *expr);
+grn_obj *grn_expr_module_list_get_function(grn_ctx *ctx,
+                                           grn_obj *expr,
+                                           unsigned int i);
+grn_rc grn_expr_module_list_get_arguments(grn_ctx *ctx,
+                                          grn_obj *expr,
+                                          unsigned int i,
+                                          grn_obj *arguments);
+
 #ifdef __cplusplus
 }
 #endif
